==> atari800_4.2.0.orig.tar.gz: atari800-4.2.0/src/libatari800/exit.c <==
/*
 * libatari800/main.c - Atari800 as a library - exit/monitor interface
 *
 * Copyright (c) 2001-2002 Jacek Poplawski
 * Copyright (C) 2001-2014 Atari800 development team (see DOC/CREDITS)
 * Copyright (c) 2016-2019 Rob McMullen
 *
 * This file is part of the Atari800 emulator project which emulates
 * the Atari 400, 800, 800XL, 130XE, and 5200 8-bit computers.
 *
 * Atari800 is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Atari800 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Atari800; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "config.h"
#include <stdio.h>
#include <string.h>

/* Atari800 includes */
#include "log.h"


/* This is placed in a separate file so other programs that include this code
 in their own makefile can redefine this function and point to their own
 debugger interface.
*/

int PLATFORM_Exit(int run_monitor)
{
	Log_flushlog();

	return 1;  /* always continue. Leave it to the client to exit */
}


/*
vim:ts=4:sw=4:
*/

==> atari800_5.2.0.orig.tar.gz: atari800-5.2.0/src/libatari800/exit.c <==
/*
 * libatari800/main.c - Atari800 as a library - exit/monitor interface
 *
 * Copyright (c) 2001-2002 Jacek Poplawski
 * Copyright (C) 2001-2014 Atari800 development team (see DOC/CREDITS)
 * Copyright (c) 2016-2019 Rob McMullen
 *
 * This file is part of the Atari800 emulator project which emulates
 * the Atari 400, 800, 800XL, 130XE, and 5200 8-bit computers.
 *
 * Atari800 is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Atari800 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Atari800; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "config.h"
#include <stdio.h>
#include <string.h>

/* Atari800 includes */
#include "log.h"


/* This is placed in a separate file so other programs that include this code
 in their own makefile can redefine this function and point to their own
 debugger interface.
*/

int PLATFORM_Exit(int run_monitor)
{
	Log_flushlog();

	return 0;  /* always exit. There is no monitor in libatari800 */
}


/*
vim:ts=4:sw=4:
*/
